@@ -125,6 +125,26 @@ static long merge_chunks(char *buffer, long size, long *bytes_in_buffer) {
 	return content_length;
 }
 
+/* Find HTTP header in input buffer
+ */
+char *find_http_header(char *buffer, char *header) {
+	char *pos;
+
+	if ((pos = strcasestr(buffer, header)) == NULL) {
+		return NULL;
+	}
+
+	if (pos == buffer) {
+		return NULL;
+	}
+
+	if (*(pos - 1) != '\n') {	
+		return NULL;
+	}
+
+	return pos;
+}
+
 /* Read the request from a client socket.
  */
 int fetch_request(t_session *session) {
@@ -193,7 +213,7 @@ int fetch_request(t_session *session) {
 
 					/* Handle 100-continue
 					 */
-					if (strnstr(session->request, "Expect: 100-continue\r\n", header_length) != NULL) {
+					if (strnstr(session->request, "\nExpect: 100-continue\r\n", header_length) != NULL) {
 						send_buffer(session, "HTTP/1.1 100 Continue\r\n\r\n", 25);
 						send_buffer(session, NULL, 0);
 					}
@@ -202,7 +222,7 @@ int fetch_request(t_session *session) {
 
 			if (header_length != -1) {
 				if ((content_length == -1) && (chunked_request == false)) {
-					if ((strstart = strcasestr(session->request, hs_conlen)) != NULL) {
+					if ((strstart = find_http_header(session->request, hs_conlen)) != NULL) {
 						/* Request has Content-Length
 						 */
 						strstart += 16;
@@ -254,7 +274,7 @@ int fetch_request(t_session *session) {
 								}
 							}
 						}
-					} else if (strcasestr(session->request, hs_chunked) != NULL) {
+					} else if (find_http_header(session->request, hs_chunked) != NULL) {
 						/* Chunked transfer encoding
 						 */
 						if (store_on_disk) {
@@ -723,7 +743,7 @@ bool validate_url(t_session *session) {
 #ifdef ENABLE_MONITOR
 	if (session->config->monitor_enabled) {
 		monitor_count_exploit_attempt(session);
-		monitor_event("Invalid URL %s for %s", session->uri, session->host->hostname.item[0]);
+		//monitor_event("Invalid URL %s for %s", session->uri, session->host->hostname.item[0]);
 	}
 #endif
 
