@@ -426,7 +426,7 @@ static int handle_admin(t_admin *admin, t_config *config) {
 			md5_bin2hex(digest, encrypted);
 			memset(line, 0, MAX_CMD_SIZE);
 
-			if ((admin->authenticated = (strcmp(encrypted, config->tomahawk_port->binding_id) == 0)) == false) {
+			if ((admin->authenticated = (strcmp_rtap(encrypted, config->tomahawk_port->binding_id) == 0)) == false) {
 				retval = cc_DISCONNECT;
 				fprintf(admin->fp, "Password incorrect\n\n");
 			} else {
